#
# spec file for package klavaro
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1500
%define espeak    espeak-ng-compat
%else
%define espeak    espeak
%endif
Name:           klavaro
Version:        3.14
Release:        1.2
Summary:        Typing tutor
License:        GPL-3.0-or-later
Group:          Amusements/Teaching/Other
URL:            https://klavaro.sourceforge.io/
Source:         https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  cairo-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  intltool
BuildRequires:  libcurl-devel
BuildRequires:  libgnutls-devel
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtkdatabox) >= 1.0
BuildRequires:  pkgconfig(libxml-2.0)
Recommends:     %{espeak}
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif

%description
Klavaro  is a touch typing tutor that is very
flexible and supports customizable keyboard
layouts. Users can edit and save new or unknown
keyboard layouts, as the basic course provided by
the program was designed to not depend on specific
layouts.

%lang_package

%prep
%setup -q

%build
# Disable static linking when libgtkdatabox gtk3 appears
%configure --disable-shared
%make_build

%install
%make_install

%fdupes -s %{buildroot}%{_datadir}

%find_lang %{name}

%if 0%{?suse_version} >= 1500
%suse_update_desktop_file -r klavaro Education X-KDE-Edu-Teaching
%else
%suse_update_desktop_file -r klavaro Education Teaching
%endif

%files -f %{name}.lang
%{_bindir}/%{name}
%license COPYING
%doc AUTHORS ChangeLog NEWS README TODO
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/%{name}/
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%changelog
* Thu Aug 31 2023 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 3.14
  * appdata ==> metainfo for desktop stuff.
  * Non-deprecated replacements for icon names.
  * fix Progress chart for basic module showing lesson 0 as lesson 1.
  * fix Spell correction: editting ==> editing.
  * fix Semicolon at end of keyword entries in klavaro.desktop.in.
  * fix Memory leak on trans_lang_get_similar function.
  * add Hindi support.
  * add Indonesian translation.
  * update Croatian,  Romenian translation
* Sat Mar 26 2022 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 3.13
  * Fixed Close button on About dialog.
  * Added French layout from AFNOR: azerty (amélioré).
  * Updated translations: Croatian, Greek (partial), Portuguese (Portugal)
- fix website URL
- removed _service file: use the upstream tarball directly
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.12
  * Turkish translation added
  * Indonesian support added.
- Build with system GtkDatabox3
* Mon Nov 16 2020 Elisei Roca <eroca@suse.com> - 3.11
- add _service file
- remove klavaro-devel package because the header files are gone
- update to 3.11
  2020-08-18  Felipe Castro (-) <fefcas@gmail.com>;
  * Release 3.11
  * Fixed:
  - Dutch typos correction on paragraphs.
  * Added:
  - keyboard: dvorak_de_bone
  * Updated translations:
  - Esperanto.
  - French.
  - Portuguese (BR).
  - Portuguese (PT).
  - Russian.
  - Serbian.
  - Ukrainian.
  - Vietnamese.
  * Added translations:
  - Romanian (very partial).
  2020-05-30  Felipe Castro (-) <fefcas@gmail.com>;
  * Release 3.10
  * Added:
  - Support for Tibetan.
  * Changed:
  - Checking for Werror=format-security at src/Makefile.am
  - Applying Debian patches 02, 03, 04 and 05.
  - Not installing GtkDataBox's include headers anymore.
  - dvorak_fr_bepo.kbd: apostrophe now is typographic.
  * Updated translations:
  - Basque.
  - Croatian.
  - Hungarian.
  - Italian.
  - Serbian.
* Tue Sep 24 2019 lars@linux-schulserver.de - 3.09
- update to 3.09
  * Fixed:
  - Internet ranking server now is https://klavaro.sourceforge.io/top10/
  - Top10 window showing always external scores when changing language
  combobox.
  - Portugal Portuguese code (pt) defined as pt_PT.
  - Man page updated.
  - Disabling beeps internally too.
  - qwertz_sk_2.kbd is a qwerty one: --> qwerty_sk.kbd (Slovakia)
  - qwertz_sk.kbd is for Slovenia:  -->  qwertz_si.kbd
  - Contry code for Slovenia is sk, not sl.
  - Using $(rootdatadir) for Gnome metadata.
  * Added:
  - Validation limits before putting scorings on Top 10.
  - Logging touch timings from last session for all modules:
  $HOME/.local/share/klavaro/deviation_MODULE.txt
  - Portuguese translation, from Portugal (pt).
  - Hotkey Ctrl+F: font configuration.
  - Hotkey Ctrl+KP_plus: increase spin buttons.
  - Hotkey Ctrl+KP_minus: decrease spin buttons.
  - Hotkeys Ctrl+R or Escape: cancel current practice, start a new one.
  - Alternative colors toggle button in tutor window. At first time run,
  a default "dark mode" is copied to the file: $HOME/.config/klavaro/altcolor.ini
  Hotkey: Ctrl+A for alternative colors.
  - qwertz_sk_2.kbd keyboard layout for Slovenia.
  - /usr/.../share/klavaro/preferences_darkmode.ini as dark colors example.
  * Removed:
  - Beeps, as they were not reliable.
  * Updated translations:
  - Dutch.
  - French.
  - Swedish.
- splitted out -devel package for header files
- removed klavaro-3.00-paragraph-ru-fix.patch : fixed upstream
- needs now cairo-devel and libgnutls-devel as build requires
- use SSL for Url and Source
- ran spec-cleaner
* Mon Mar 18 2019 lars@linux-schulserver.de - 3.05
- update to 3.05
  * Fixed:
  - Crashing when not recognized option from command-line.
  * Added:
  - Instructions for typing with the shift keys (in the introduction).
  - Explanation about the blank lessons after 43, in basic module.
  - Possible to reset progress log of each module individually, as well
    as character error charts or touch times charts in adaptability.
  - Possible to use paragraphs complete texts in Speed module (klavaro -x).
  * Updated translations:
  - Croatian.
  - Danish.
  - Esperanto.
  - Polish.
  - Portuguese (BR).
  - Russian.
  - Ukrainian.
  From Release 3.04
  * Fixed:
  - Tutor window was not allowing to shrink horizontaly, only growing.
    Now its horizontal scroll is allowed to appear, liberating it to shrink.
  - Colors again on keyboard buttons, they had disappeared.
  - Proficiency log file shown as touch time per key in adaptability
    charts  was being corrupted eventually.
  - Statistics after practice were being colorized.
  - Crashing? when no <libintl.h> installed on the system and? using
    ./configure --disable-nls
  - bg.paragraphs and bg.words chars fixed.
  - da.paragraphs and da.words chars fixed. (ét -> et)
  - fi.paragraphs char fixed.
  - hr.paragraphs chars fixed.
  - kk.paragraphs chars fixed?
  - nl.paragraphs chars fixed? (wéér -> weer)
  - pa.paragraphs chars fixed. (removed English word quadrant)
  - ru.paragraphs chars fixed.
  - sr.paragraphs chars fixed. (ascii quotes: " ")
  - uk.paragraphs chars fixed.
  - qwertz_de.kbd chars fixed. (Ä Ö -> ä ö)
  - Substituted deprecated stuff on Glade file, for GTK+-3.8
  * Changed:
  - Inserting a little indentation on tutor texts paragraphs.
  - Using 2 copies of character pool for the basic lessons generator,
    for a little bit more double sequences of same char.
  - More difficult to get a special proficiency training session on
    adaptability, but easier to get an special error training.
  - Using new GtkDataBox update, from GIT repository, changes may appear
    in the progress charts.
  - Some deprecated GTK+-3 functions were updated to version 3.8.
  * Added:
  - Merge all the basic lessons in the progress chart: Lesson '0'.
  - In fluidity, manages Ctrl+h to work as Backspace (delete -1 char)
    and Ctrl+w as Ctrl+Backspace (clean up all errors).
  - dvorak_de_adnw.kbd    "Aus der Neue Welt" german keyboard layout.
  - dvorak_us_left.kbd    Dvorak left hand layout.
  - dvorak_us_rigth.kbd   Dvorak rigth hand layout.
* Tue Mar 13 2018 aloisio@gmx.com
- Use espeak-ng when available
- Remove superfluous buildtime requirement
* Sun Aug  6 2017 kkirill@opensuse.org
- update to 3.03
  + Fixed:
  - el.paragraphs minor bugs fixed.
  - Counting unicode characters apart for touchs-per-second calculation and
    also handling IM context.
  - Gurmukhi keyboard for Jhelum is from Pakistan (kept version for
    India). Removed extra "bindi" from 'P' key-position.
  - Updated klavaro.appdata.xml file, e.g. added the kudo ModernToolkit.
  - Added GenericName in klavaro.desktop file.
  - Resource leak at translation.c (fh obtained with fopen but had no fclose).
  - Default keyboard for Finnish is [qwerty_se], not [querty_se].
  - Blinking cursor GSource timeout error.
  - Not plotting data for English UK, Español; Castellano and possibly other
    languages.
  + Changed:
  - Max number of customizable basic lessons increased to 256.
  - ar.paragraphs updated with some quotes, no more religious or
    political texts.
  - Allowing the tutor window to shrink more.
  - Using Gurmukhi script to show Punjabi (pa) option in "Language" at main menu
    window.
  + Added translations:
  - Korean support.
  - Serbian.
  + Updated translations:
  - Arabic.
  - French.
* Sun Nov  6 2016 mailaender@opensuse.org
- use https://en.opensuse.org/SourceUrls
- https://en.opensuse.org/openSUSE:Packaging_Conventions_RPM_Macros
- use upstream provided .desktop file
* Thu Sep  1 2016 kkirill@opensuse.org
- update to 3.02
  + Fixed:
  - Using portable GTK function to access Klavaros's Top 10 URL.
  + Changed:
  - pa.paragraphs updated.
  + Added translations:
  - Catalan.
  - Croatian.
  + Updated translations:
  - Swedish.
  - Polish.
  - Czech.
  - Italian.
  - Galician.
  - French.
  - Finnish completed: words and paragraphs added.
* Wed Sep 10 2014 kkirill@opensuse.org
- update to 3.01
  + Added:
  - Gurmukhi Jhelum keyboard for Punjabi language (normal and shifted).
  - AppData file, with description and screenshot links for software
    centers.
  - AppIcons with resolutions 64x64 and 96x96.
  + Fixed:
  - Punjabi characters now are managed correctly.
  - Maybe the annoying wrapping bug has also been fixed (Hallelujah!).
  - Layout querty_ca_quebec.kbd not presenting isolated acute anymore,
    using now the letter "é".
  - Reactivated the spin button to select the basic lesson on progress
    charts.
  - Return of value -1 for pointer in gtk_databox_get_graphs(), now
    returning NULL.
  - Windows issue when selecting default language (e.g. with en_IN).
  - Now the internal GtkDatabox library has its name moved to
    "gtkdataboks", to avoid conflicting with the upstream library.
  + Changed:
  - Reset button put a bit aside from the Close button, in the progress
    charts.
  - New phrases for C.paragraphs (default English), avoiding political
    subjects.
  - Some new phrases for pt_br.paragraphs.
  - Backspace allows to repeat accomplished lesson in basic module.
  + Added translations:
  - Punjabi.
  - Slovenian.
  + Fixed messages:
  - Typo: Kunf-fu mastering --> Kung-fu mastery
  - Idiom: make better --> do better
  + Updated translations:
  - Czech.
  - Galician.
  - German.
  - Swedish (also sv.paragraphs and sv.words).
- remove upsteaamed patch: klavaro-3.00-wrong-return-value.patch
* Mon Aug 25 2014 kkirill@opensuse.org
- update to 3.00:
  + Fixed:
  - Typo: prefered --> preferred
  - Manpage: minus as hyphen corrected with escapes (\-)
  + Changed:
  - Migrated from GTK2 to GTK3.
  - GtkDatabox is incorporated statically, because its last release does
    not support GTK3 yet.
  - FontSelectionDialog is deprecated, so using now a FontButton.
  - Some translatable messages were reviewed.
  - Default background color for the tutor practice text came back to
    ice-white: colors are easier customizable in the preferences.ini file.
  + Added:
  - Keywords in the klavaro.desktop file.
  - Goals for touch typing skill are now configurable through the
    prefences.ini file.
  - Programmer Dvorak keyboard layout added (dvorak_us_prog.kbd).
  + Updated translations:
  - Basque.
  - Danish.
  - Dutch.
  - Esperanto.
  - Greek.
  - Hungarian.
  - Portuguese (Brazilian).
  - Ukrainian.
  - Vietnamese.
  + Added translations:
  - Finnish (partial).
- add klavaro-3.00-paragraph-ru-fix.patch to replace hard to type
  typographic chars with simple
- add klavaro-3.00-wrong-return-value.patch to fix 64-bit
  portability issue in gtkdatabox.c
* Wed Feb  5 2014 fstrba@suse.com
- update to 2.01:
  + Fixed:
  - Icon indication in the .desktop file now gives only the relative
    name (klavaro), not the complete absolute path: more general.
  - Italian translation, _Next <==> _Previous (by hand, waiting update
    from the Translation Project)
  - Symbols '-' and '\' at middle of words are avoided now; and '´' is
    avoided at end of words (adapt module).
  - It was aborting in Windows systems where LANG=en_US.
  + Changed:
  - Makefile.am (ACLOCAL_AMFLAGS): New variable.
  - (EXTRA_DIST): Add m4/ChangeLog.
  - configure.ac (AM_GNU_GETTEXT_VERSION): Bump to 0.18.3.
  + Updated translations:
  - Kazakh
  - Khirgyz
- release notes for 2.00:
  + Changed:
  - ru.paragraphs for practicing module fluidity in Russian.
  - Not relocating very old paths to the "newer" ones.
- removed patches:
  * klavaro-1.9.5-paragraph-ru-fix.patch not needed
* Fri Sep  6 2013 kkirill@opensuse.org
- update to 1.9.9:
  + Added translations:
  - Greek
  + Fixed:
  - Turkish keyboard layouts.
  + Changed:
  - Updated the greek keyboard layout, the old one is renamed
    to qwerty_old.
  - Default foreground color for the tutor practice text made
    more greenish.
  - Updated autotools and gettext infrastructure.
- release notes for 1.9.8:
  + Updated translations:
  - Esperanto.
  - French.
  - Vietnamese.
  - Kirghiz.
* Mon Feb 25 2013 lars@linux-schulserver.de
- updated to 1.9.7:
  + Added:
  - Bulgarian translation
  + Updated:
  - Kyrgyz translation
  - Galician translation
  + Changed:
  - Galician text for fluidity practice, it had content
    with violence.
  - Galician words for speed practice.
  - Filtering progress charts according to keyboard (basic
    & adapt) or language (velo & fluid).
    See side effects on NEWS!
  - Dismissing keys which are not in the current keyboard
    (keyset), in the error/speed accounting process for the
    adapt personal practicing. Results for these are saved now
    in specific files, for each keyboard.
    See side effects on NEWS!
* Sun Jan 20 2013 kkirill@opensuse.org
- updated to 1.9.6:
  + Added:
  - Kyrgyz translation (partial)
  - Telugu translation (partial)
  - Workman (US) layout
  + Changed:
  - Explicit linking with gmodule  -2.0, to avoid problem with
    Implicit DSO linking (in Fedora).
  - Orange color for keys now a bit darker.
  - Basic lessons with only 2 letters are 4 lines only.
  - Russian internal sub  -dictionary changed, because of
    spelling errors.
  + Updated:
  - Automake files (1.11.6)
  - Basque translation
  - Russian translation
- removed klavaro-1.9.4-dso.patch (fixed upstream)
* Sat Jun 23 2012 kkirill@opensuse.org
- updated to 1.9.5:
  + Added:
  - Warning about the need to use backspace on the fluidity
    module.
  - Wolof translation.
  + Fixed:
  - dvorak_es_nativo.kbd: it missed the key <
  - Blinking cursor wasn't lighted on at every touch for basic
    and adapt modules.
  + Changed:
  - Upper limit for speed charts now is 120 WPM (before it was
    100).
  + Updated translations:
  - Danish.
  - Dutch.
  - Esperanto.
  - French.
  - German.
  - Portuguese.
  - Spanish.
  - Ukrainian.
  - Vietnamese.
* Sun Mar  4 2012 kkirill@opensuse.org
- added klavaro-1.9.4-dso.patch to fix linking with gmodule-2.0
* Wed Feb 15 2012 lars@linux-schulserver.de
- update to 1.9.4:
  + Added:
  ++ Spanish Dvorak layout: dvorak_es_nativo.kbd
  ++ Swiss layouts: qwertz_ch_de.kbd, qwertz_ch_fr.kbd
  + General color configuration through the preferences.ini file.
  + Detecting difficult keys through timing, not just errors.
  + Enabled fluidity practice with the complete text, not randomizing
    the paragraphs (set "0 paragraphs" to activate this).
  + Updated the man documentation, including a description for the
    configuration of colors.
  + Fixed virtual keyboard: foreground of keys were fixed in black,
    to avoid issues with dark GTK themes.
  + Updated translations:
  - Czech
  - Danish
  - Dutch
  - Esperanto
  - Hungarian
  - Portuguese
  - Ukrainian
  - Vietnamese
- build with optflags
* Sat Aug 27 2011 kirill.kirillov@gmail.com
- update to 1.9.3:
  + added Canadian French Dvorak layout: dvorak_ca_fr.kbd
  + fixed several mistakes in Polish text data
  + made a duplicated qwerty_us layout the default for Polland
  + duplicated qwerty_us for China
  + moved qwerty_nb.kbd to qwerty_no.kbd
  + added workaround to avoid Pango's wrapping-algorithm to mess up
    with the text when the cursor blinks
  + code cleanup (new warnings removed)
  + added autoconf checks for headers: curl/curl.h and gtkdatabox.h
* Sun Jun 19 2011 matthias@mailaender.name 
- update to 1.9.2:
  + updated translations: Simplified Chinese, Italian, French,
    Urdu, Vietnamese
  + added Canadian French (Quebec) layout
  + fixed editable basic lessons goes from 44 through 60
    (corrected the tip in the editing button)
* Mon Apr  4 2011 kirill.kirillov@gmail.com
- update to 1.9.0:
  + added speech support
  + the fluidness server changed to SF.net
* Thu Mar 24 2011 kirill.kirillov@gmail.com
- update to 1.8.1:
  + new translations were added for Basque, Ukrainian, Italian,
  and Simplified Chinese
  + desktop file installation
  + intltool infrastructure, to translate the desktop file comment
* Wed Dec 22 2010 kirill.kirillov@gmail.com
- update to 1.7.4:
  + added Basque translation.
  + Neo2 keyboard layout (kind of German Dvorak)
  + updates to other translations
- release notes for 1.7.3:
  + removed gtkdatabox from the pkg-config way
  + updated translations
- release notes for 1.7.2:
  + added Canadian multilingual kbd
  + updated translations
* Wed Sep  1 2010 kirill.kirillov@gmail.com
- update to 1.7.0:
  + Fixed Internet scoring for AMD64 machines (gint32).
  + Kazakh translation.
  + Russian typewriter keyboard (by Sietse Brouwer).
* Mon May  3 2010 alexandre@exatati.com.br
- update to 1.5.0:
  + Now checking for the math lib (libm) in the configure.in.
  + Hebrew keyboard layout (the old one was kept anyway).
  + Now error-profile exercises may be disabled in the adaptability
    module; one just has to toggle the little warning button at the top
    right corner.
- release notes for 1.4.1:
  + Added Norwegian Bokmål translation.
- Spec file cleaned with spec-cleaner.
* Sun Nov 29 2009 Kirill Kirillov <kirill.kirillov@gmail.com>
- update to 1.4.0
  + Updating the Top10 scores after downloading the remote results
  + Not depending on libsexy anylong, using GTK+ 2.16 instead
  + Updated Czech translation
  + Added Arabic translation
* Fri Sep 25 2009 kirill.kirillov@gmail.com
- update to 1.3.1
  + Updated translations: Danish, German, Portuguese, Esperanto,
    Vietnamese.
- relase notes for 1.3.0:
  + Strings and numbers together to allow translation for every language.
  + Code cleanup.
  + Using mnemonics for buttons instead of hotkeys.
  + Parsing GTK command line options.
* Tue Aug 11 2009 kirill.kirillov@gmail.com
- update to 1.2.2
  + New kind of exercise in the adaptability module: character salad
    based on the error profile of the user. In order to reach that,
    the user should practice a little bit, accumulating more than 200
    errors
  + The colected errors are shown in the adaptability charts.
  + Double spaces after full stops are generated if the option
    'double_spaces=true' is present in the section [tutor] of the
    'preferences.ini' file; this affects only the fluidity module.
  + The colors of the blinking cursor may be modified through the
    'preferences.ini' file. The variables are in the section [colors]
    and they are 'cursor_blink_bg' and 'cursor_blink_fg'.
  + User data now goes into the $XDG_DATA_HOME subdir
    ($HOME/.local/share/klavaro), but user configuration files remain
    in $XDG_CONFIG_HOME
  + Eliminated scores from the /var/games subdir, so those data spread
    in the users' home dirs.
* Tue May 19 2009 kirill.kirillov@gmail.com
- update to 1.2.0:
  + Norwegian keyboard layout
  + French Dvorak BÉPO keyboard layout
  + Esperanto Dvorak keyboard layouts
  + Complete interface refactoring, towards simplification and good appeal
  + New subdir for user data: $HOME/.config/klavaro
  + Simplified the internal code for most available languages (e.g. es_ES ==> es)
  + Code clean-up, replacing Glade-2 with GtkBuilder (and Glade-3)
* Sat Apr 11 2009 kirill.kirillov@gmail.com
- fix saving of local scoring (/var/games/klavaro)
* Sat Apr 11 2009 kirill.kirillov@gmail.com
- update to 1.1.9:
  + New CGI server for automatically updating the online ranking
  + Showing the error ratio within the statistics text for all modules
  + Showing also the score for the fluidness tests
  + Vietnamese default exercise files for velocity and fluidness modules
  + Colemak layout file: colemak_us
* Thu Dec 11 2008 kirill.kirillov@gmail.com
- update to 1.1.8:
  + Localization for Vietnamese
  + Localization for Bangla/Bengali
  + Using 'libcurl' instead of 'wget' and 'ftp-upload'
  + Enabling font selection also at the introduction of any tutor module
  + Avoid duplication of users in the contest rankings
  + Re-enabled logging the progress for the velocity module
  + Unlimiting word lenght for the velocity module
  + Improved loading dictionaries for the velocity module
  + Fixed loading intro texts to enable long UTF-8 files
* Thu Oct 30 2008 kirill.kirillov@gmail.com
- update to 1.1.7:
  + Added localization support for United Kingdom and specific Dvorak layout
    "dvorak_uk"
  + Logging the keyboard layout name to the fluidness contest
  + Delay that keeps the blinking cursor on, at each keypress
  + Tutor comments about performance try to be less rude
  + Least number of chars to enter the fluidness rankings now is 500
- relase notes for 1.1.6:
  + Added Urdu localization support
  + German translation was updated and completed
  + Other fixes
- relase notes for 1.1.5:
  + Updated French translation
  + Added Japanese keyboard layout: "qwerty_jp"
* Thu Oct 30 2008 lars@linux-schulserver.de
- fix file permissions of klavaro_helper
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Sat Sep  6 2008 kirill.kirillov@gmail.com
- Update to version 1.1.4
  + eliminated dependence on the utility "dos2unix"
  + added man-file to klavaro_helper
  + avoid so many records per user in the rankings
* Sun Aug  3 2008 kirill.kirillov@gmail.com
- Update to version 1.1.2
  + Fix expanded informations about scoring when not using the "C" locale
  + In the velocity and fluidness modules, now it's possible to drop also text files
  + Hungarian translation was updated
* Sat Jun 28 2008 kirill.kirillov@gmail.com
- Update to version 1.1.1
  + Scoring and ranking (Top 10) for the fluidness exercises.
  + Online contest for Top 10 ranking (only for Linux).
  + Some translation updates and other small fixes
* Tue Jun  3 2008 kirill.kirillov@gmail.com
- Update to version 1.0.8
  + Copy a text from extern (Ctrl-C) and paste it (Ctrl-V) as custom
    velocity and fluidness exercises. Also drag and drop was implemented.
  + May start directly on any of the 4 modules: basic, adapt, velo or fluid;
  + GTK+ icons for various buttons.
  + Specific layout for United Kingdom: "qwerty_uk.kbd".
* Mon May 19 2008 lars@linux-schulserver.de
- fix rpm group
* Mon Mar 17 2008 lars@linux-schulserver.de
- beautify specfile
- use update_desktop_files to get the desktop file installed
  automatically during rpm install
- own some locale-dirs not owned by filesystem package
* Mon Jan 28 2008 kirill.kirillov@gmail.com
- Initial build of version 1.0.7
  + thanks to original spec by Dries Verachtert <dries@ulyssis.org>
